# $Id: td_make.in,v 12.38 2019/12/27 00:39:06 tom Exp $
# common definitions for makefiles built over TD_LIB library.
# vile:makemode

SHELL	= /bin/sh


####### (Environment) ##########################################################
prefix		= /usr
exec_prefix	= ${prefix}

bindir		= ${exec_prefix}/bin
libdir		= /usr/lib64
datarootdir	= ${prefix}/share
mandir		= /usr/man
datadir		= ${datarootdir}

TD_LIB = /usr/lib64
TD_INC = /usr/include/td
TD_CFG = /usr/share/td

AR		= ar
ARFLAGS		= -curvU
RM		= rm -f
LINT		= 
LINT_OPTS	= 
CTAGS		= ctags
ETAGS		= etags

CC		= gcc
CPP		= gcc -E
INSTALL		= /usr/bin/ginstall -c 
INSTALL_PROGRAM	= ${INSTALL} -s
INSTALL_DATA	= ${INSTALL} -m 644
RANLIB		= ranlib
MAKE_OPTS	= 

EXTRA_CFLAGS	= 
CFLAGS		= -O2 -fPIC
LINK		= $(CC) $(CFLAGS)

INSTALL_BIN	= $(DESTDIR)$(bindir)
INSTALL_INC	= $(DESTDIR)$(includedir)
INSTALL_LIB	= $(DESTDIR)$(libdir)
INSTALL_MAN	= $(DESTDIR)$(mandir)

####### (Command-line Options) #################################################
EXTRA_CPPFLAGS	= 
CPPFLAGS	= -D_DEFAULT_SOURCE -D_XOPEN_SOURCE=500
CPP_CONFIG	= -I. -I$(TD_INC) -DHAVE_CONFIG_H $(CPPFLAGS) $(EXTRA_CPPFLAGS)
CPP_OPTS	= $(CPP_CONFIG) $(EXTRA_CPP_OPTS)

x		= 
LIB_DEPS	= $(TD_LIB)/libtd.a
LIB_ARGS	=  -L/lib64 -L$(TD_LIB) -ltd 

CURSES_LIBS	=  -L/lib64 -L$(TD_LIB) -ltd -lncurses  

DATE		= echo '** '`date` >> $@

LINTLIBS	= -ltd 
LINTOPTS	= $(LINT_OPTS) $(CPP_OPTS) -DNO_IDENT $(LINTLIBS)

####### (Standard Lists) #######################################################
# don't put .a into CLEAN, because VERDIX-ADA uses that for source!
CLEAN	= *.[oi] *.lint *.bak *.log *.out *.tst .nfs* *.pure* core tags
DESTROY	=$(SHELL) -c 'for i in *;do case $$i in RCS);; *) $(RM) $$i;;esac;done;exit 0'
RUN_TESTS=$(SHELL) -c './run_test.sh 2>&1 | tee -a $@.out'

PTYPES_H =	$(TD_INC)/ptypes.h \
		$(TD_INC)/td_ext.h \
		$(TD_INC)/td_lib.h \
		$(TD_INC)/td_config.h
CURSES_H =	$(PTYPES_H) \
		$(TD_INC)/td_curse.h
QSORT_H =	$(PTYPES_H) \
		$(TD_INC)/td_qsort.h
RCSDEFS_H =	$(PTYPES_H) \
		$(TD_INC)/rcsdefs.h \
		$(TD_INC)/deltree.h
SCCSDEFS_H =	$(PTYPES_H) \
		$(TD_INC)/sccsdefs.h

####### (Development) ##########################################################
CPROTO	= cproto -e -i -fo'\\n\\t\\t' -fp'\\n\\t\\t'

LINT_EACH = $(SHELL) -c 'for i in $?;do echo $$i:; $(LINT) $(LINTOPTS) $$i >>$@;done'

.SUFFIXES: .c .o .a .i .proto .lint .tst .man $(SUFFIX_MAN) .txt .pdf .ps .html

.c.o:
	
	$(CC) $(CPP_OPTS) $(CFLAGS) $(EXTRA_CFLAGS) -c $*.c
.o.a:
	@$(AR) $(ARFLAGS) $@ $*.o
	-@$(RM) $*.o
.c.a:
	
	$(CC) $(CPP_OPTS) $(CFLAGS) $(EXTRA_CFLAGS) -c $*.c
	@$(AR) $(ARFLAGS) $@ $*.o
	-@$(RM) $*.o

.c.i:		; $(CC) $(CPP_OPTS) -E -C $*.c >$@
.c.proto:	; $(CPROTO) $(CPP_OPTS) $*.c >$@
.c.lint:	; $(LINT) $(LINTOPTS) $*.c >$@

.c.tst:
	$(CC) -o $@ -DTEST $(CFLAGS) $(EXTRA_CFLAGS) $(CPP_OPTS) $*.c $Z $(LIB_ARGS)

#SUFFIX_MAN = .txt  .html
#CLEAN__MAN = *.txt  *.html
#NROFF	= /usr/bin/nroff
#
#.man.txt:
#	-$(RM) $@
#	$(NROFF) -man $? >$@

SUFFIX_MAN = .txt .pdf .ps .png  .html
CLEAN__MAN = *.txt *.pdf *.ps *.png  *.html
GROFF	= /usr/bin/groff

.man.ps :
	$(SHELL) -c "tbl $*.man | $(GROFF) -man" >$@

.man.txt :
	GROFF_NO_SGR=stupid $(SHELL) -c "tbl $*.man | $(GROFF) -Tascii -man | col -bx" >$@

.ps.pdf :
	ps2pdf $*.ps

.man.html :
	$(TD_CFG)/man2html.sh $* man man >$@

